AutoSubmitFormAfterCountdownWidget | django_cradmin API Document

    import AutoSubmitFormAfterCountdownWidget from 'django_cradmin/scripts/django_cradmin/widgets/AutoSubmitFormAfterCountdownWidget.js'

public class | source

# AutoSubmitFormAfterCountdownWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → AutoSubmitFormAfterCountdownWidget

Autosubmit form after a timeout widget.

#### Example:

    <form action="/test" method="post">
        <p>
           Will autosubmit in
           <span data-ievv-jsbase-widget="cradmin-auto-submit-form-after-countdown"
                 data-ievv-jsbase-widget-config='{
                   "timeoutSeconds": 5
                 }'>
               5
           </span>
           seconds!
        </p>
    </form>

## Constructor Summary

Public Constructor
public | constructor(element: *) |

## Method Summary

Public Methods
public | destroy() |
public | getDefaultConfig(): * |

## Public Constructors

### public constructor(element: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |

## Public Methods

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*